@@ -4,8 +4,6 @@ from igloo.models.utils import wrapWith
 
 
 class CategorySeriesNodeLoader(DataLoader):
-    cache = False
-
     def __init__(self, client, id):
         super().__init__()
         self.client = client
@@ -71,7 +69,7 @@ class CategorySeriesNode:
                 "categorySeriesNode", "series"])
 
         def wrapper(res):
-            from .category_series_value import CategorySeriesVariable
+            from .category_series_variable import CategorySeriesVariable
             return CategorySeriesVariable(self.client, res["id"])
 
         return wrapWith(res, wrapper)
