@@ -28,13 +28,13 @@ class SubscriptionRoot:
         async for data in self.client.subscribe(('subscription{thingCreated(%s){id}}' % (environmentId_arg)).replace('()', '')):
             yield Thing(self.client, data["thingCreated"]["id"])
 
-    async def thing_claimed(self, environment_id=undefined, id=undefined):
+    async def thing_paired(self, environment_id=undefined, id=undefined):
         environmentId_arg = parse_arg(
             "environmentId", environment_id)
         id_arg = parse_arg("id", id)
 
-        async for data in self.client.subscribe(('subscription{thingClaimed(%s%s){id}}' % (environmentId_arg, id_arg)).replace('()', '')):
-            yield Thing(self.client, data["thingClaimed"]["id"])
+        async for data in self.client.subscribe(('subscription{thingPaired(%s%s){id}}' % (environmentId_arg, id_arg)).replace('()', '')):
+            yield Thing(self.client, data["thingPaired"]["id"])
 
     async def environment_created(self):
         async for data in self.client.subscribe(('subscription{environmentCreated(){id}}' % ()).replace('()', '')):
@@ -53,11 +53,11 @@ class SubscriptionRoot:
         async for data in self.client.subscribe(('subscription{floatSeriesNodeCreated(%s){id}}' % (seriesId_arg)).replace('()', '')):
             yield FloatSeriesNode(self.client, data["floatSeriesNodeCreated"]["id"])
 
-    async def category_series_node_created(self, series_id=undefined):
-        seriesId_arg = parse_arg("seriesId", series_id)
+    # async def category_series_node_created(self, series_id=undefined):
+    #     seriesId_arg = parse_arg("seriesId", series_id)
 
-        async for data in self.client.subscribe(('subscription{categorySeriesNodeCreated(%s){id}}' % (seriesId_arg)).replace('()', '')):
-            yield CategorySeriesNode(self.client, data["categorySeriesNodeCreated"]["id"])
+    #     async for data in self.client.subscribe(('subscription{categorySeriesNodeCreated(%s){id}}' % (seriesId_arg)).replace('()', '')):
+    #         yield CategorySeriesNode(self.client, data["categorySeriesNodeCreated"]["id"])
 
     async def access_token_created(self):
         async for data in self.client.subscribe(('subscription{accessTokenCreated(){id}}' % ()).replace('()', '')):
@@ -83,7 +83,7 @@ class SubscriptionRoot:
             yield PendingShare(self.client, data["pendingShareUpdated"]["id"])
 
     async def pending_share_accepted(self, ):
-        async for data in self.client.subscribe(('subscription{pendingShareAccepted(){id sender receiver role environment}}' % ()).replace('()', '')):
+        async for data in self.client.subscribe(('subscription{pendingShareAccepted(){id sender recipient role environment}}' % ()).replace('()', '')):
             yield data["pendingShareAccepted"]
 
     async def pending_share_declined(self, ):
@@ -111,12 +111,12 @@ class SubscriptionRoot:
             yield PendingTransfer(self.client, data["pendingTransferCreated"]["id"])
 
     async def pending_transfer_accepted(self):
-        async for data in self.client.subscribe(('subscription{pendingTransferAccepted(){sender{id} receiver{id} environment{id} id}}').replace('()', '')):
+        async for data in self.client.subscribe(('subscription{pendingTransferAccepted(){sender{id} recipient{id} environment{id} id}}').replace('()', '')):
             res = data["pendingTransferAccepted"]
             res["sender"] = User(
                 self.client, res["sender"]["id"])
-            res["receiver"] = User(
-                self.client, res["receiver"]["id"])
+            res["recipient"] = User(
+                self.client, res["recipient"]["id"])
             res["environment"] = Environment(
                 self.client, res["environment"]["id"])
 
@@ -165,12 +165,12 @@ class SubscriptionRoot:
         async for data in self.client.subscribe(('subscription{floatSeriesNodeUpdated(%s%s){id}}' % (seriesId_arg, id_arg)).replace('()', '')):
             yield FloatSeriesNode(self.client, data["floatSeriesNodeUpdated"]["id"])
 
-    async def category_series_node_updated(self, series_id=undefined, id=undefined):
-        seriesId_arg = parse_arg("seriesId", series_id)
-        id_arg = parse_arg("id", id)
+    # async def category_series_node_updated(self, series_id=undefined, id=undefined):
+    #     seriesId_arg = parse_arg("seriesId", series_id)
+    #     id_arg = parse_arg("id", id)
 
-        async for data in self.client.subscribe(('subscription{categorySeriesNodeUpdated(%s%s){id}}' % (seriesId_arg, id_arg)).replace('()', '')):
-            yield CategorySeriesNode(self.client, data["categorySeriesNodeUpdated"]["id"])
+    #     async for data in self.client.subscribe(('subscription{categorySeriesNodeUpdated(%s%s){id}}' % (seriesId_arg, id_arg)).replace('()', '')):
+    #         yield CategorySeriesNode(self.client, data["categorySeriesNodeUpdated"]["id"])
 
     async def notification_updated(self, thing_id=undefined, id=undefined):
         thingId_arg = parse_arg("thingId", thing_id)
@@ -194,12 +194,12 @@ class SubscriptionRoot:
         async for data in self.client.subscribe(('subscription{floatSeriesNodeDeleted(%s%s)}' % (seriesId_arg, id_arg)).replace('()', '')):
             yield data["floatSeriesNodeDeleted"]
 
-    async def category_series_node_deleted(self, series_id=undefined, id=undefined):
-        seriesId_arg = parse_arg("seriesId", series_id)
-        id_arg = parse_arg("id", id)
+    # async def category_series_node_deleted(self, series_id=undefined, id=undefined):
+    #     seriesId_arg = parse_arg("seriesId", series_id)
+    #     id_arg = parse_arg("id", id)
 
-        async for data in self.client.subscribe(('subscription{categorySeriesNodeDeleted(%s%s)}' % (seriesId_arg, id_arg)).replace('()', '')):
-            yield data["categorySeriesNodeDeleted"]
+    #     async for data in self.client.subscribe(('subscription{categorySeriesNodeDeleted(%s%s)}' % (seriesId_arg, id_arg)).replace('()', '')):
+    #         yield data["categorySeriesNodeDeleted"]
 
     async def thing_deleted(self, environment_id=undefined, id=undefined):
         environmentId_arg = parse_arg("environmentId", environment_id)
@@ -208,12 +208,12 @@ class SubscriptionRoot:
         async for data in self.client.subscribe(('subscription{thingDeleted(%s%s)}' % (environmentId_arg, id_arg)).replace('()', '')):
             yield data["thingDeleted"]
 
-    async def thing_unclaimed(self, environment_id=undefined, id=undefined):
+    async def thing_unpaired(self, environment_id=undefined, id=undefined):
         environmentId_arg = parse_arg("environmentId", environment_id)
         id_arg = parse_arg("id", id)
 
-        async for data in self.client.subscribe(('subscription{thingUnclaimed(%s%s)}' % (environmentId_arg, id_arg)).replace('()', '')):
-            yield data["thingUnclaimed"]
+        async for data in self.client.subscribe(('subscription{thingUnpaired(%s%s)}' % (environmentId_arg, id_arg)).replace('()', '')):
+            yield data["thingUnpaired"]
 
     async def environment_deleted(self, id=undefined):
         id_arg = parse_arg("id", id)
